OC.L10N.register(
    "settings",
    {
    "Wrong password" : "Yalnış şifrə",
    "No user supplied" : "Heç bir istifadəçiyə mənimsədilmir",
    "Authentication error" : "Təyinat metodikası",
    "Please provide an admin recovery password, otherwise all user data will be lost" : "Xahış olunur inzibatçı geriyə qayıdış şifrəsini təqdim edəsiniz, əks halda bütün istfadəçi datası itəcək.",
    "Wrong admin recovery password. Please check the password and try again." : "İnzibatçı geriyə qayıdış şifrəsi yalnışdır. Xahiş olunur şifrəni yoxlayıb yenidən təkrar edəsiniz.",
    "Backend doesn't support password change, but the user's encryption key was successfully updated." : "Arxa sonluq şifrənin dəyişdirilməsini dəstəkləmir ancaq, istifadəçi şifrələmə açarı uğurla yeniləndi.",
    "Unable to change password" : "Şifrəni dəyişmək olmur",
    "Enabled" : "İşə salınıb",
    "Not enabled" : "İşə salınıb",
    "Federated Cloud Sharing" : "Federal Cloud Paylaşım",
    "Group already exists." : "Qrup artılq mövcduddur.",
    "Unable to add group." : "Qrupu əlavə etmək mümkün deyil. ",
    "Unable to delete group." : "Qrupu silmək mümkün deyil.",
    "log-level out of allowed range" : "jurnal-səviyyəsi izin verilən aralıqdan kənardır",
    "Saved" : "Saxlanıldı",
    "test email settings" : "sınaq məktubu quraşdırmaları",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Məktubun yollanmasında səhv baş verdi. Xahiş olunur öz quraşdırmalarınıza yenidən göz yetirəsiniz.(Error: %s)",
    "Email sent" : "Məktub göndərildi",
    "You need to set your user email before being able to send test emails." : "Test məktubu göndərməzdən öncə, siz öz istifadəçi poçtunuzu təyin etməlisiniz.",
    "Invalid mail address" : "Yalnış mail ünvanı",
    "A user with that name already exists." : "Bu adla istifadəçi artıq mövcuddur.",
    "Unable to create user." : "İstifadəçi yaratmaq mümkün deyil.",
    "Your %s account was created" : "Sizin %s hesab yaradıldı",
    "Unable to delete user." : "İstifadəçini silmək mümkün deyil.",
    "Forbidden" : "Qadağan",
    "Invalid user" : "İstifadəçi adı yalnışdır",
    "Unable to change mail address" : "Mail ünvanını dəyişmək olmur",
    "Email saved" : "Məktub yadda saxlanıldı",
    "Your full name has been changed." : "Sizin tam adınız dəyişdirildi.",
    "Unable to change full name" : "Tam adı dəyişmək olmur",
    "Security & setup warnings" : "Təhlükəsizlik & işə salma xəbərdarlıqları",
    "Sharing" : "Paylaşılır",
    "External Storage" : "Kənar depo",
    "Cron" : "Cron",
    "Log" : "Jurnal",
    "Updates" : "Yenilənmələr",
    "Couldn't remove app." : "Proqram təminatını silmək mümkün olmadı.",
    "Language changed" : "Dil dəyişdirildi",
    "Invalid request" : "Səhv müraciət",
    "Admins can't remove themself from the admin group" : "İnzibatçılar özlərini inzibatçı qrupundan silə bilməz",
    "Unable to add user to group %s" : "İstifadəçini %s qrupuna əlavə etmək mümkün olmadı",
    "Unable to remove user from group %s" : "İstifadəçini %s qrupundan silmək mümkün olmadı",
    "Couldn't update app." : "Proqram təminatını yeniləmək mümkün deyil.",
    "Are you really sure you want add \"{domain}\" as trusted domain?" : "\"{domain}\" adını inamlı domainlər siyahısına əlavə etməyinizdən əminsinizmi?",
    "Add trusted domain" : "İnamlı domainlərə əlavə et",
    "Sending..." : "Göndərilir...",
    "All" : "Hamısı",
    "No apps found for your version" : "Sizin versiya üçün proqram tapılmadı",
    "Update to %s" : "Yenilə bunadək %s",
    "Please wait...." : "Xahiş olunur gözləyəsiniz.",
    "Error while disabling app" : "Proqram təminatını dayandırdıqda səhv baş verdi",
    "Disable" : "Dayandır",
    "Enable" : "İşə sal",
    "Error while enabling app" : "Proqram təminatını işə saldıqda səhv baş verdi",
    "Updating...." : "Yenilənir...",
    "Error while updating app" : "Proqram təminatı yeniləndikdə səhv baş verdi",
    "Updated" : "Yeniləndi",
    "Uninstalling ...." : "Silinir...",
    "Error while uninstalling app" : "Proqram təminatını sildikdə səhv baş verdi",
    "Uninstall" : "Sil",
    "Valid until {date}" : "Müddətədək keçərlidir {date}",
    "Delete" : "Sil",
    "Select a profile picture" : "Profil üçün şəkli seç",
    "Very weak password" : "Çox asan şifrə",
    "Weak password" : "Asan şifrə",
    "So-so password" : "Elə-belə şifrə",
    "Good password" : "Yaxşı şifrə",
    "Strong password" : "Çətin şifrə",
    "Groups" : "Qruplar",
    "Unable to delete {objName}" : "{objName} silmək olmur",
    "A valid group name must be provided" : "Düzgün qrup adı təyin edilməlidir",
    "deleted {groupName}" : "{groupName} silindi",
    "undo" : "geriyə",
    "no group" : "qrup yoxdur",
    "never" : "heç vaxt",
    "deleted {userName}" : "{userName} silindi",
    "add group" : "qrupu əlavə et",
    "Changing the password will result in data loss, because data recovery is not available for this user" : "Şifrənin dəyişdirilməsi data itkisinə gətirəcək ona görə ki, datanın bərpası bu istifadəçi üçün movcud deyil.",
    "A valid username must be provided" : "Düzgün istifadəçi adı daxil edilməlidir",
    "A valid password must be provided" : "Düzgün şifrə daxil edilməlidir",
    "A valid email must be provided" : "Düzgün email təqdim edilməlidir",
    "__language_name__" : "__AZ_Azerbaijan__",
    "Unlimited" : "Limitsiz",
    "Personal info" : "Şəxsi məlumat",
    "Sync clients" : "Müştəriləri sinxronizasiya et",
    "Everything (fatal issues, errors, warnings, info, debug)" : "Hər şey(ən pis hadisələr, səhvlər, xəbərdarlıqlar, məlmat, araşdırma səhvləri)",
    "Info, warnings, errors and fatal issues" : "Məlmat, xəbərdarlıqlar, səhvlər və ən pis hadisələr",
    "Warnings, errors and fatal issues" : "Xəbərdarlıqlar, səhvlər və ən pis hadisələr",
    "Errors and fatal issues" : "Səhvlər və ən pis hadisələr",
    "Fatal issues only" : "Yalnız ən pis hadisələr",
    "None" : "Heç bir",
    "Login" : "Giriş",
    "Plain" : "Adi",
    "NT LAN Manager" : "NT LAN Manager",
    "SSL" : "SSL",
    "TLS" : "TLS",
    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Yalnız-Oxuma işə salınıb. Bu web-interface vasitəsilə edilən bəzi konfiqlərin qarşısını alır. Bundan başqa, fayl əllə edilən istənilən yenilınmə üçün yazılma yetkisinə sahib olmalıdır. ",
    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP göründüyü kimi, daxili doc bloklarının ayrılması işini görəcək. Bu bəzi özək proqramlarını əlçatılmaz edə bilər.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Bu ola bilər ki, cache/accelerator such tərəfindən cağırılıb hansi ki, Zend OPcache və eAccelerator-da olduğu kimidir.",
    "Your server is running on Microsoft Windows. We highly recommend Linux for optimal user experience." : "Sizin servef Microsoft Windows-da işləyir. Optimal istifadəçi təcrübəsi üçün, təkidlə Linux məsləhət görürük.",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "PHP-nin modulu 'fileinfo' mövcud deyil. Mime-type təyin edilməsi üçün,  modulun aktivləşdirilməsini təkidlə məsləhət görürük.",
    "System locale can not be set to a one which supports UTF-8." : "UTF-8 dsətklənən sistemdə daxili vaxt və dil təyinatı ola bilməz. ",
    "This means that there might be problems with certain characters in file names." : "Bu o deməkdir ki, orda faylın adında bəzi simvollarda problemlər var.",
    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Biz təkidlə təklif edirik ki, göstərilən dillər üçün tələb edilən paketləri sisteminizdə yükləyəsiniz: %s.",
    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Eger sizin yüklənməniz root domain-də yüklənməyibsə və sistem cron-u istifadə edirsə, orda URL generasiyası ilə bağlı problemləriniz ola bilər. Bu problemləri aşmaq üçün xahiş olunur yüklənmə vaxtı \"overwrite.cli.url\" opsiyasını config.php faylında webroot ünvanı olaraq təyin edəsiniz (Məsləhətdir: \"%s\")",
    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "CRON işini CLİ-dan yerinə yetirmək mümkün olmadı. Görünən texniki səhv baş verdi.",
    "Open documentation" : "Sənədləri aç",
    "Allow apps to use the Share API" : "Proqramlara izin verin ki, Paylaşım API-sindən istifadə edə bilsinlər.",
    "Allow users to share via link" : "Istifadəçilərə link üzərindən paylaşım etməyə izin vermək",
    "Allow public uploads" : "Ümumi yüklənmələrə izin vermək",
    "Enforce password protection" : "Şifrə müdafiəsini həyata keçirmək",
    "Set default expiration date" : "Susmaya görə olan bitmə vaxtını təyin edin",
    "Allow users to send mail notification for shared files" : "Yayımlanmış fayllar üçün, istifadəçilərə məktubla xəbərdarlığın yollanmasına izin verir",
    "Expire after " : "Bitir sonra",
    "days" : "günlər",
    "Enforce expiration date" : "Bitmə tarixini həyata keçir",
    "Allow resharing" : "Yenidən paylaşıma izin",
    "Restrict users to only share with users in their groups" : "İstifadəçiləri yalnız yerləşdikləri qrup üzvləri ilə paylaşım edə bilmələrini məhdudla",
    "Allow users to send mail notification for shared files to other users" : "İstifadəçilərə etdikləri paylaşımı digər istifadəçilərə mail vasitəsilə xəbərdarlıq göndərilməsinə izin verin",
    "Exclude groups from sharing" : "Qrupları paylaşımdan ayır",
    "These groups will still be able to receive shares, but not to initiate them." : "Bu qruplar paylaşımları hələdə ala biləcəklər ancaq, yarada bilməyəcəklər",
    "Last cron job execution: %s." : "Son cron yerinə yetirilməsi işi: %s.",
    "Last cron job execution: %s. Something seems wrong." : "Son cron yerinə yetirilməsi: %s. Nə isə yalnış görünür.",
    "Cron was not executed yet!" : "Cron hələ yerinə yetirilməyib!",
    "Execute one task with each page loaded" : "Hər səhifə yüklənməsində bir işi yerinə yetir",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php qeydə alınmış webcron servisdir hansi ki, http üzərindən hər 15 dəqiqədən bir cron.php çağırır.",
    "Use system's cron service to call the cron.php file every 15 minutes." : "Sistemin cron servisindən istifadə edin ki, cron.php faylını hər 15 dəqiqədən bir işə salasınız.",
    "This is used for sending out notifications." : "Kənara xəbərdarlıqları ötürmək üçün bu istifadə edilir.",
    "Send mode" : "Göndərmə rejimi",
    "Encryption" : "Şifrələnmə",
    "From address" : "Ünvandan",
    "mail" : "poçt",
    "Authentication method" : "Qeydiyyat metodikası",
    "Authentication required" : "Qeydiyyat tələb edilir",
    "Server address" : "Server ünvanı",
    "Port" : "Port",
    "Credentials" : "Səlahiyyətlər",
    "SMTP Username" : "SMTP İstifadəçi adı",
    "SMTP Password" : "SMTP Şifrəsi",
    "Store credentials" : "Səlahiyyətləri saxla",
    "Test email settings" : "Email qurmalarını test et",
    "Send email" : "Email yolla",
    "Download logfile" : "Jurnal faylını endir",
    "More" : "Yenə",
    "Less" : "Az",
    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "Jurnal faylı 100MB-dan çoxdur. Onun endirilməsi müəyyən vaxt ala bilər.",
    "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "SQLinte verilənlər bazası kimi istifadə edilir. Geniş tətbiq üçün,  biz məsləhət görürük ki, arxa sonluqda fərqli verilənlər bazasından istifadə edəsiniz. ",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Xüsusilə fayl sinxronizasiyası üçün desktop client-dən istifadə edilərsə, SQLite məsləhət görülmür.",
    "How to do backups" : "Rezerv nüsxələr neçə edilisin",
    "Advanced monitoring" : "İrəliləmiş monitoring",
    "Version" : "Versiya",
    "Developer documentation" : "Yaradıcı sənədləşməsi",
    "Documentation:" : "Sənədləşmə:",
    "Show description …" : "Açıqlanmanı göstər ...",
    "Hide description …" : "Açıqlamanı gizlət ...",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Bu proqram yüklənə bilməz ona görə ki, göstərilən asılılıqlar yerinə yetirilməyib:",
    "Enable only for specific groups" : "Yalnız spesifik qruplara izin ver",
    "Uninstall App" : "Proqram təminatını sil",
    "Common Name" : "Ümumi ad",
    "Valid until" : "Vaxtadək keçərlidir",
    "Issued By" : "Tərəfindən yaradılıb",
    "Valid until %s" : "Keçərlidir vaxtadək %s",
    "Import root certificate" : "root sertifikatı import et",
    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Ey ora,<br><br>ancaq deyirik ki, sizin artiq %s hesabınız var.<br><br>Sizin istifadəçi adınız: %s<br>Yetkilidir: <a href=\"%s\">%s</a><br><br>",
    "Cheers!" : "Şərəfə!",
    "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Ey ora,\n\nancaq deyirik ki, sizin artiq %s hesabınız var.\n\nizin istifadəçi adınız: %s\nYetkilidir: %s\n\n",
    "Forum" : "Forum",
    "Profile picture" : "Profil şəkli",
    "Upload new" : "Yenisini yüklə",
    "Remove image" : "Şəkili sil",
    "Cancel" : "Dayandır",
    "Full name" : "Tam ad",
    "No display name set" : "Ekranda adı dəsti yoxdur",
    "Email" : "Email",
    "Your email address" : "Sizin email ünvanı",
    "No email address set" : "Email ünvanı dəsti yoxdur",
    "You are member of the following groups:" : "Siz göstərilən qrupların üzvüsünüz:",
    "Password" : "Şifrə",
    "Unable to change your password" : "Sizin şifrəni dəyişmək mümkün olmadı",
    "Current password" : "Hazırkı şifrə",
    "New password" : "Yeni şifrə",
    "Change password" : "Şifrəni dəyiş",
    "Language" : "Dil",
    "Help translate" : "Tərcüməyə kömək",
    "Name" : "Ad",
    "Username" : "İstifadəçi adı",
    "Done" : "Edildi",
    "Get the apps to sync your files" : "Fayllarınızın sinxronizasiyası üçün proqramları götürün",
    "Desktop client" : "Desktop client",
    "Android app" : "Android proqramı",
    "iOS app" : "iOS proqramı",
    "If you want to support the project\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\tor\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!" : "Əgər siz proektə dəstək vermək istəyirsinizsə\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">Təkmilləşdirməyə üzv</a>\n\t\tyada\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">söz yaymaq</a>!",
    "Show First Run Wizard again" : "İlk işəsalma sehirbazını yenidən göstər",
    "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "Tərəfindən yaradılıb{communityopen}ownCloud cəmiyyəti{linkclose},   {githubopen}mənbə kodları{linkclose} altında lisenziya edilib {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}.",
    "Show storage location" : "Depo ünvanını göstər",
    "Show last log in" : "Son girişi göstər",
    "Show user backend" : "Daxili istifadəçini göstər",
    "Send email to new user" : "Yeni istifadəçiyə məktub yolla",
    "Show email address" : "Email ünvanını göstər",
    "E-Mail" : "E-Mail",
    "Create" : "Yarat",
    "Admin Recovery Password" : "İnzibatçı bərpa şifrəsi",
    "Enter the recovery password in order to recover the users files during password change" : "Şifrə dəyişilməsi müddətində, səliqə ilə bərpa açarını daxil et ki, istifadəçi fayllları bərpa edilsin. ",
    "Add Group" : "Qrup əlavə et",
    "Group" : "Qrup",
    "Everyone" : "Hamı",
    "Admins" : "İnzibatçılar",
    "Default Quota" : "Susmaya görə olan norma",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Xahiş olunur depo normasını daxil edəsiniz (Məs: \"512 MB\" yada \"12 GB\")",
    "Other" : "Digər",
    "Full Name" : "Tam ad",
    "Group Admin for" : "üçün qrup inzibatçısı",
    "Quota" : "Norma",
    "Storage Location" : "Depo yeri",
    "User Backend" : "İstifadəçı bazası",
    "Last Login" : "Son giriş",
    "change full name" : "tam adı dəyiş",
    "set new password" : "yeni şifrə təyin et",
    "change email address" : "email ünvanını dəyiş",
    "Default" : "Susmaya görə"
},
"nplurals=2; plural=(n != 1);");
